# Log4j-CVE-2021-44228 detector scanner playbook

[![CI](https://github.com/lucab85/log4j-cve-2021-44228/actions/workflows/ci.yml/badge.svg)](https://github.com/lucab85/log4j-cve-2021-44228/actions/workflows/ci.yml)

Ansible playbook to verify target Linux hosts using the official Red Hat Log4j detector script for Log4Shell (CVE-2021-44228).

[Red Hat version 1.2 detector 2021-12-20](https://access.redhat.com/security/vulnerabilities/RHSB-2021-009).

The result is saved in a txt file under `detector_dir` (default: `/tmp/cve-2021-44228/`).

## Ansible Galaxy role

Available in Ansible Galaxy role as [lucab85.ansible_role_log4shell](https://galaxy.ansible.com/lucab85/ansible_role_log4shell):

```bash
ansible-galaxy install lucab85.ansible_role_log4shell
```

## How to run

Default variables scan all the `/var/` path for affected files.
Customize the `vars.yml` file for more options.

```bash
ansible-playbook log4j-cve-2021-44228.yml
```

## Dependencies

None.

## Requirements

ansible 2.9+

## Variables vars.yml

default values:

```yaml
sh_detector: "cve-2021-44228--2021-12-20-1836.sh"
sh_signature: 'cve-2021-44228--2021-12-20-1836.sh.asc'
detector_baseurl: 'https://access.redhat.com/sites/default/files/'
detector_path: "/var/"
detector_dir: "/tmp/cve-2021-44228/"
detector_run_dir: 'tmp'
detector_options: '-n -d --no-progress --scan {{ detector_path }}'
gpg_keyid: '7514F77D8366B0D9'
gpg_public_key: 'gpg --keyserver pgp.mit.edu --recv {{ gpg_keyid }}'
clean_run_before: true
delete_after: false
verify_gpg: true
```

## demo execution

```bash
PLAY [detector for Apache Log4j (CVE-2021-44228)] ******************************

TASK [Gathering Facts] *********************************************************
ok: [demo]

TASK [include_vars] ************************************************************
ok: [demo]

TASK [dependency present] ******************************************************
ok: [demo]

TASK [create detector directory] ***********************************************
ok: [demo]

TASK [download detector file(s)] ***********************************************
ok: [demo] => (item=cve-2021-44228--2021-12-20-1836.sh)
ok: [demo] => (item=cve-2021-44228--2021-12-20-1836.sh.asc)

TASK [gpg public key] **********************************************************
changed: [demo]

TASK [gpg verify detector] *****************************************************
changed: [demo]

TASK [remove any detector run directory] ***************************************
changed: [demo]

TASK [create detector run directory] *******************************************
changed: [demo]

TASK [run detector/scanner] ****************************************************
changed: [demo]

TASK [files in detector run directory] ************
ok: [demo]

TASK [print vulnerable path(s) found] ******************************************
ok: [demo] => {
    "vulnerable": {
        "changed": false,
        "examined": 1,
        "failed": false,
        "files": [],
        "matched": 0,
        "msg": "All paths examined",
        "skipped_paths": {}
    }
}

TASK [remove detector directory] ***********************************************
skipping: [demo]

PLAY RECAP *********************************************************************
demo                       : ok=12   changed=5    unreachable=0    failed=0    skipped=1    rescued=0    ignored=0   

```

## License

MIT / BSD

## Author Information

This role was created in 2021 by [Luca Berton](https://www.lucaberton.it/), author of [Ansible Pilot](https://www.ansiblepilot.com/).

## Ansible Pilot

More information

- [Website](https://www.ansiblepilot.com/)
- [Ansible Pilot YouTube channel](https://www.youtube.com/channel/UC5MNbTYRHSCu9vAki3z9SmA)
- [Medium](https://ansiblepilot.medium.com/)
- [Twitter](https://twitter.com/ansiblepilot)

## Donate

Thank you for supporting me

- [Patreon](https://patreon.com/lucaberton)
- [Buy me a pizza](https://www.buymeacoffee.com/lucab)
- [GitHub sponsor](https://github.com/sponsors/lucab85)
